
// File: index.xml

// File: classAttLimits.xml
%feature("docstring") AttLimits "

Attributes and limits of a fit parameter, and coupling between these properties.

C++ includes: AttLimits.h
";

%feature("docstring")  AttLimits::AttLimits "AttLimits::AttLimits()
";

%feature("docstring")  AttLimits::isFixed "bool AttLimits::isFixed() const 
";

%feature("docstring")  AttLimits::isLimited "bool AttLimits::isLimited() const 
";

%feature("docstring")  AttLimits::isUpperLimited "bool AttLimits::isUpperLimited() const 
";

%feature("docstring")  AttLimits::isLowerLimited "bool AttLimits::isLowerLimited() const 
";

%feature("docstring")  AttLimits::isLimitless "bool AttLimits::isLimitless() const 
";

%feature("docstring")  AttLimits::lowerLimit "double AttLimits::lowerLimit() const 
";

%feature("docstring")  AttLimits::upperLimit "double AttLimits::upperLimit() const 
";

%feature("docstring")  AttLimits::setFixed "void AttLimits::setFixed(bool isFixed)
";

%feature("docstring")  AttLimits::toString "std::string AttLimits::toString() const 
";


// File: classAttributes.xml
%feature("docstring") Attributes "

Attributes for a fit parameter. Currently, the only attribute is fixed/free.

C++ includes: Attributes.h
";

%feature("docstring")  Attributes::Attributes "Attributes::Attributes()
";

%feature("docstring")  Attributes::setFixed "void Attributes::setFixed(bool is_fixed)
";

%feature("docstring")  Attributes::isFixed "bool Attributes::isFixed() const 
";

%feature("docstring")  Attributes::isFree "bool Attributes::isFree() const 
";


// File: classFitKernel.xml
%feature("docstring") FitKernel "

Main class to setup and run a minimization. Implemented in pimpl idiom.

C++ includes: FitKernel.h
";

%feature("docstring")  FitKernel::FitKernel "FitKernel::FitKernel()
";

%feature("docstring")  FitKernel::~FitKernel "FitKernel::~FitKernel()
";

%feature("docstring")  FitKernel::clear "void FitKernel::clear()
";

%feature("docstring")  FitKernel::setMinimizer "void FitKernel::setMinimizer(const std::string &minimizerName, const std::string &algorithmName=\"\")

Sets minimizer with given name and algorithm type.

Parameters:
-----------

minimizerName: 
The name of the minimizer

algorithmName: 
Optional name of the minimizer's algorithm 
";

%feature("docstring")  FitKernel::setMinimizer "void FitKernel::setMinimizer(IMinimizer *minimizer)
";

%feature("docstring")  FitKernel::minimizer "const IMinimizer * FitKernel::minimizer() const

Returns the minimizer. 
";

%feature("docstring")  FitKernel::addFitParameter "void FitKernel::addFitParameter(const std::string &name, double value, const AttLimits &limits, double step)

Adds fit parameter. 
";

%feature("docstring")  FitKernel::setObjectiveFunction "void FitKernel::setObjectiveFunction(objective_function_t func)
";

%feature("docstring")  FitKernel::setGradientFunction "void FitKernel::setGradientFunction(gradient_function_t func, int ndatasize)
";

%feature("docstring")  FitKernel::minimize "void FitKernel::minimize()
";

%feature("docstring")  FitKernel::reportResults "std::string FitKernel::reportResults() const

Returns multi-line string to report results of minimization. 
";

%feature("docstring")  FitKernel::fitParameters "FitParameterSet * FitKernel::fitParameters()
";

%feature("docstring")  FitKernel::fitParameters "const FitParameterSet * FitKernel::fitParameters() const 
";

%feature("docstring")  FitKernel::functionCalls "int FitKernel::functionCalls() const

Returns number of objective function calls. 
";


// File: classFitKernelImpl.xml
%feature("docstring") FitKernelImpl "

The implementation of class  FitKernel.

C++ includes: FitKernelImpl.h
";

%feature("docstring")  FitKernelImpl::FitKernelImpl "FitKernelImpl::FitKernelImpl()
";

%feature("docstring")  FitKernelImpl::~FitKernelImpl "FitKernelImpl::~FitKernelImpl()
";

%feature("docstring")  FitKernelImpl::clear "void FitKernelImpl::clear()
";

%feature("docstring")  FitKernelImpl::setMinimizer "void FitKernelImpl::setMinimizer(IMinimizer *minimizer)

Sets minimizer. 
";

%feature("docstring")  FitKernelImpl::addFitParameter "void FitKernelImpl::addFitParameter(IFitParameter *par)

Adds fit parameter. 
";

%feature("docstring")  FitKernelImpl::setObjectiveFunction "void FitKernelImpl::setObjectiveFunction(objective_function_t func)
";

%feature("docstring")  FitKernelImpl::setGradientFunction "void FitKernelImpl::setGradientFunction(gradient_function_t func, int ndatasize)
";

%feature("docstring")  FitKernelImpl::minimize "void FitKernelImpl::minimize()
";

%feature("docstring")  FitKernelImpl::reportResults "std::string FitKernelImpl::reportResults() const

Reports results of minimization in the form of multi-line string. 
";

%feature("docstring")  FitKernelImpl::fitParameters "FitParameterSet * FitKernelImpl::fitParameters()
";

%feature("docstring")  FitKernelImpl::minimizer "IMinimizer * FitKernelImpl::minimizer()
";

%feature("docstring")  FitKernelImpl::functionCalls "int FitKernelImpl::functionCalls() const

Number of objective function calls. 
";


// File: classFitOptions.xml
%feature("docstring") FitOptions "

General fitting options.

C++ includes: FitOptions.h
";

%feature("docstring")  FitOptions::FitOptions "FitOptions::FitOptions()
";

%feature("docstring")  FitOptions::~FitOptions "FitOptions::~FitOptions()
";

%feature("docstring")  FitOptions::derivEpsilon "double FitOptions::derivEpsilon() const 
";

%feature("docstring")  FitOptions::setDerivEpsilon "void FitOptions::setDerivEpsilon(double deriv_epsilon)
";

%feature("docstring")  FitOptions::stepFactor "double FitOptions::stepFactor() const 
";

%feature("docstring")  FitOptions::setStepFactor "void FitOptions::setStepFactor(double step_factor)
";


// File: classFitParameterSet.xml
%feature("docstring") FitParameterSet "

The set of fit parameters.

C++ includes: FitParameterSet.h
";

%feature("docstring")  FitParameterSet::FitParameterSet "FitParameterSet::FitParameterSet()
";

%feature("docstring")  FitParameterSet::~FitParameterSet "FitParameterSet::~FitParameterSet()
";

%feature("docstring")  FitParameterSet::clear "void FitParameterSet::clear()

Clears all defined parameters. 
";

%feature("docstring")  FitParameterSet::size "size_t FitParameterSet::size() const

Returns number of parameters. 
";

%feature("docstring")  FitParameterSet::begin "FitParameterSet::iterator FitParameterSet::begin()

Container iterators. 
";

%feature("docstring")  FitParameterSet::begin "FitParameterSet::const_iterator FitParameterSet::begin() const 
";

%feature("docstring")  FitParameterSet::end "FitParameterSet::iterator FitParameterSet::end()
";

%feature("docstring")  FitParameterSet::end "FitParameterSet::const_iterator FitParameterSet::end() const 
";

%feature("docstring")  FitParameterSet::addFitParameter "void FitParameterSet::addFitParameter(IFitParameter *par)

Adds fit parameter. 
";

%feature("docstring")  FitParameterSet::fitParameter "const IFitParameter * FitParameterSet::fitParameter(const std::string &name) const

Returns fit parameter by given name. 
";

%feature("docstring")  FitParameterSet::fitParameter "IFitParameter * FitParameterSet::fitParameter(const std::string &name)
";

%feature("docstring")  FitParameterSet::values "std::vector< double > FitParameterSet::values() const

Returns values of all defined parameters. 
";

%feature("docstring")  FitParameterSet::setValues "void FitParameterSet::setValues(const std::vector< double > &pars_values)

Sets values for all defined parameters. 
";

%feature("docstring")  FitParameterSet::valuesDifferFrom "bool FitParameterSet::valuesDifferFrom(const std::vector< double > &par_values, double tolerance=2.0) const

Returns true if parameters already have the given values. 
";

%feature("docstring")  FitParameterSet::errors "std::vector< double > FitParameterSet::errors() const

Returns errors of all defined parameters. 
";

%feature("docstring")  FitParameterSet::setErrors "void FitParameterSet::setErrors(const std::vector< double > &pars_errors)

Sets errors to all parameters. 
";

%feature("docstring")  FitParameterSet::freeFitParameterCount "size_t FitParameterSet::freeFitParameterCount() const

Returns number of free parameters. 
";

%feature("docstring")  FitParameterSet::fixAll "void FitParameterSet::fixAll()

Fix all parameters. 
";

%feature("docstring")  FitParameterSet::releaseAll "void FitParameterSet::releaseAll()

Release all parameters. 
";

%feature("docstring")  FitParameterSet::setFixed "void FitParameterSet::setFixed(const std::vector< std::string > &pars, bool is_fixed)

Set fixed flag for parameters from the list. 
";

%feature("docstring")  FitParameterSet::correlationMatrix "corr_matrix_t FitParameterSet::correlationMatrix() const 
";

%feature("docstring")  FitParameterSet::setCorrelationMatrix "void FitParameterSet::setCorrelationMatrix(const corr_matrix_t &matrix)

Sets resulting correlation matrix. 
";


// File: classGeneticMinimizer.xml
%feature("docstring") GeneticMinimizer "

Wrapper for the CERN ROOT Genetic minimizer.

C++ includes: GeneticMinimizer.h
";

%feature("docstring")  GeneticMinimizer::GeneticMinimizer "GeneticMinimizer::GeneticMinimizer()
";

%feature("docstring")  GeneticMinimizer::~GeneticMinimizer "GeneticMinimizer::~GeneticMinimizer()

Sets tolerance on the function value at the minimum. Minimization will stop when the estimated vertical distance to the minimum (EDM) is less than 0.001*tolerance*ErrorDef. Here ErrorDef=1.0 for chi squared fit and ErrorDef=0.5 for negative log likelihood fit. 
";

%feature("docstring")  GeneticMinimizer::setTolerance "void GeneticMinimizer::setTolerance(double value)
";

%feature("docstring")  GeneticMinimizer::tolerance "double GeneticMinimizer::tolerance() const 
";

%feature("docstring")  GeneticMinimizer::setPrintLevel "void GeneticMinimizer::setPrintLevel(int value)

Sets minimizer internal print level. 
";

%feature("docstring")  GeneticMinimizer::printLevel "int GeneticMinimizer::printLevel() const 
";

%feature("docstring")  GeneticMinimizer::setMaxIterations "void GeneticMinimizer::setMaxIterations(int value)

Sets maximum number of iterations to try at each step. 
";

%feature("docstring")  GeneticMinimizer::maxIterations "int GeneticMinimizer::maxIterations() const 
";

%feature("docstring")  GeneticMinimizer::setPopulationSize "void GeneticMinimizer::setPopulationSize(int value)

Sets population size. 
";

%feature("docstring")  GeneticMinimizer::populationSize "int GeneticMinimizer::populationSize() const 
";

%feature("docstring")  GeneticMinimizer::setRandomSeed "void GeneticMinimizer::setRandomSeed(int value)

Sets random seed. 
";

%feature("docstring")  GeneticMinimizer::randomSeed "int GeneticMinimizer::randomSeed() const 
";

%feature("docstring")  GeneticMinimizer::statusToString "std::string GeneticMinimizer::statusToString() const override

Returns string representation of current minimizer status. 
";

%feature("docstring")  GeneticMinimizer::statusMap "std::map< std::string, std::string > GeneticMinimizer::statusMap() const override

Returns map of string representing different minimizer statuses. 
";


// File: classGSLLevenbergMarquardtMinimizer.xml
%feature("docstring") GSLLevenbergMarquardtMinimizer "

Wrapper for CERN ROOT facade of the GSL Levenberg-Marquardt minimizer. It's a facade to ROOT::Math::GSLNLSMinimizer which adapts ROOT::Math::GSLMultiFit minimizers to some CERN ROOT generic minimizer interface. ROOT::Math::GSLMultiFit, in turn, is a facade to the actual GSL's gsl_multifit_fdfsolver_type (http://www.gnu.org/software/gsl/manual/html_node/Nonlinear-Least_002dSquares-Fitting.html).

C++ includes: GSLLevenbergMarquardtMinimizer.h
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::GSLLevenbergMarquardtMinimizer "GSLLevenbergMarquardtMinimizer::GSLLevenbergMarquardtMinimizer()
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::~GSLLevenbergMarquardtMinimizer "GSLLevenbergMarquardtMinimizer::~GSLLevenbergMarquardtMinimizer()

Sets tolerance on the function value at the minimum. 
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::setTolerance "void GSLLevenbergMarquardtMinimizer::setTolerance(double value)
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::tolerance "double GSLLevenbergMarquardtMinimizer::tolerance() const 
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::setPrintLevel "void GSLLevenbergMarquardtMinimizer::setPrintLevel(int value)

Sets minimizer internal print level. 
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::printLevel "int GSLLevenbergMarquardtMinimizer::printLevel() const 
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::setMaxIterations "void GSLLevenbergMarquardtMinimizer::setMaxIterations(int value)

Sets maximum number of iterations. This is an internal minimizer setting which has no direct relation to the number of objective function calls (e.g. numberOfIteraction=5 might correspond to ~100 objective function calls). 
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::maxIterations "int GSLLevenbergMarquardtMinimizer::maxIterations() const 
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::statusToString "std::string GSLLevenbergMarquardtMinimizer::statusToString() const override

Returns string representation of current minimizer status. 
";

%feature("docstring")  GSLLevenbergMarquardtMinimizer::statusMap "std::map< std::string, std::string > GSLLevenbergMarquardtMinimizer::statusMap() const override

Returns map of string representing different minimizer statuses. 
";


// File: classGSLMultiMinimizer.xml
%feature("docstring") GSLMultiMinimizer "

Wrapper for the CERN ROOT facade of the GSL multi minimizer family (gradient descent based).

C++ includes: GSLMultiMinimizer.h
";

%feature("docstring")  GSLMultiMinimizer::GSLMultiMinimizer "GSLMultiMinimizer::GSLMultiMinimizer(const std::string &algorithmName=AlgorithmNames::ConjugateFR)
";

%feature("docstring")  GSLMultiMinimizer::~GSLMultiMinimizer "GSLMultiMinimizer::~GSLMultiMinimizer()
";

%feature("docstring")  GSLMultiMinimizer::setPrintLevel "void GSLMultiMinimizer::setPrintLevel(int value)

Sets minimizer internal print level. 
";

%feature("docstring")  GSLMultiMinimizer::printLevel "int GSLMultiMinimizer::printLevel() const 
";

%feature("docstring")  GSLMultiMinimizer::setMaxIterations "void GSLMultiMinimizer::setMaxIterations(int value)

Sets maximum number of iterations. This is an internal minimizer setting which has no direct relation to the number of objective function calls (e.g. numberOfIteraction=5 might correspond to ~100 objective function calls). 
";

%feature("docstring")  GSLMultiMinimizer::maxIterations "int GSLMultiMinimizer::maxIterations() const 
";

%feature("docstring")  GSLMultiMinimizer::statusToString "std::string GSLMultiMinimizer::statusToString() const override

Returns string representation of current minimizer status. 
";


// File: classIFitParameter.xml
%feature("docstring") IFitParameter "

A fittable parameter with value, error, step, and limits.

C++ includes: IFitParameter.h
";

%feature("docstring")  IFitParameter::IFitParameter "IFitParameter::IFitParameter()
";

%feature("docstring")  IFitParameter::IFitParameter "IFitParameter::IFitParameter(const std::string &name, double value, const AttLimits &limits=AttLimits::limitless(), double step=0.0)
";

%feature("docstring")  IFitParameter::~IFitParameter "virtual IFitParameter::~IFitParameter()
";

%feature("docstring")  IFitParameter::clone "IFitParameter * IFitParameter::clone() const 
";

%feature("docstring")  IFitParameter::name "std::string IFitParameter::name() const 
";

%feature("docstring")  IFitParameter::setName "IFitParameter & IFitParameter::setName(const std::string &name)
";

%feature("docstring")  IFitParameter::startValue "double IFitParameter::startValue() const 
";

%feature("docstring")  IFitParameter::setStartValue "void IFitParameter::setStartValue(double value)
";

%feature("docstring")  IFitParameter::value "double IFitParameter::value() const 
";

%feature("docstring")  IFitParameter::setValue "void IFitParameter::setValue(double value)
";

%feature("docstring")  IFitParameter::addPattern "IFitParameter & IFitParameter::addPattern(const std::string &pattern)
";

%feature("docstring")  IFitParameter::step "double IFitParameter::step() const 
";

%feature("docstring")  IFitParameter::setStep "IFitParameter & IFitParameter::setStep(double value)
";

%feature("docstring")  IFitParameter::error "double IFitParameter::error() const 
";

%feature("docstring")  IFitParameter::setError "void IFitParameter::setError(double value)
";

%feature("docstring")  IFitParameter::limits "const AttLimits & IFitParameter::limits() const 
";

%feature("docstring")  IFitParameter::limits "AttLimits & IFitParameter::limits()
";

%feature("docstring")  IFitParameter::setLimits "IFitParameter & IFitParameter::setLimits(const AttLimits &limits)
";

%feature("docstring")  IFitParameter::setLowerLimited "IFitParameter & IFitParameter::setLowerLimited(double bound_value)
";

%feature("docstring")  IFitParameter::setPositive "IFitParameter & IFitParameter::setPositive()
";

%feature("docstring")  IFitParameter::setNonnegative "IFitParameter & IFitParameter::setNonnegative()
";

%feature("docstring")  IFitParameter::setUpperLimited "IFitParameter & IFitParameter::setUpperLimited(double bound_value)
";

%feature("docstring")  IFitParameter::setLimited "IFitParameter & IFitParameter::setLimited(double left_bound_value, double right_bound_value)
";

%feature("docstring")  IFitParameter::setFixed "IFitParameter & IFitParameter::setFixed()
";

%feature("docstring")  IFitParameter::toString "std::string IFitParameter::toString() const 
";


// File: classFit_1_1IFunctionAdapter.xml
%feature("docstring") Fit::IFunctionAdapter "

Base class for objective function adapters, which converts user functions to minimize into the function which minimization machinery expects.

C++ includes: IFunctionAdapter.h
";

%feature("docstring")  Fit::IFunctionAdapter::IFunctionAdapter "IFunctionAdapter::IFunctionAdapter()
";

%feature("docstring")  Fit::IFunctionAdapter::~IFunctionAdapter "IFunctionAdapter::~IFunctionAdapter()
";

%feature("docstring")  Fit::IFunctionAdapter::numberOfCalls "int IFunctionAdapter::numberOfCalls() const 
";

%feature("docstring")  Fit::IFunctionAdapter::numberOfGradientCalls "int IFunctionAdapter::numberOfGradientCalls() const 
";


// File: classIMinimizer.xml
%feature("docstring") IMinimizer "

Pure virtual interface for all kind minimizers.

C++ includes: IMinimizer.h
";

%feature("docstring")  IMinimizer::IMinimizer "IMinimizer::IMinimizer()
";

%feature("docstring")  IMinimizer::~IMinimizer "virtual IMinimizer::~IMinimizer()
";

%feature("docstring")  IMinimizer::IMinimizer "IMinimizer::IMinimizer(const IMinimizer &other)=delete
";

%feature("docstring")  IMinimizer::minimizerName "virtual std::string IMinimizer::minimizerName() const =0

return name of the minimizer 
";

%feature("docstring")  IMinimizer::algorithmName "virtual std::string IMinimizer::algorithmName() const =0

return name of the minimization algorithm 
";

%feature("docstring")  IMinimizer::minimize "virtual void IMinimizer::minimize()=0

run minimization 
";

%feature("docstring")  IMinimizer::minimize_scalar "Fit::MinimizerResult IMinimizer::minimize_scalar(fcn_scalar_t, Fit::Parameters)
";

%feature("docstring")  IMinimizer::minimize_residual "Fit::MinimizerResult IMinimizer::minimize_residual(fcn_residual_t, Fit::Parameters)
";

%feature("docstring")  IMinimizer::clear "virtual void IMinimizer::clear()

clear resources (parameters) for consecutives minimizations 
";

%feature("docstring")  IMinimizer::setParameters "virtual void IMinimizer::setParameters(const FitParameterSet &parameters)=0

Sets internal minimizer parameters using external parameter list. 
";

%feature("docstring")  IMinimizer::setObjectiveFunction "virtual void IMinimizer::setObjectiveFunction(objective_function_t)
";

%feature("docstring")  IMinimizer::setGradientFunction "virtual void IMinimizer::setGradientFunction(gradient_function_t, int)
";

%feature("docstring")  IMinimizer::minValue "double IMinimizer::minValue() const

Returns minimum function value. 
";

%feature("docstring")  IMinimizer::reportOutcome "virtual std::string IMinimizer::reportOutcome() const =0
";

%feature("docstring")  IMinimizer::propagateResults "void IMinimizer::propagateResults(FitParameterSet &parameters)

Propagates results of minimization to fit parameter set. 
";

%feature("docstring")  IMinimizer::propagateResults "void IMinimizer::propagateResults(Fit::Parameters &parameters)
";

%feature("docstring")  IMinimizer::setOptions "void IMinimizer::setOptions(const std::string &options)

Sets option string to the minimizer. 
";


// File: classInfoItem.xml
%feature("docstring") InfoItem "

A name and a description.

C++ includes: MinimizerInfo.h
";

%feature("docstring")  InfoItem::InfoItem "InfoItem::InfoItem()
";

%feature("docstring")  InfoItem::InfoItem "InfoItem::InfoItem(const std::string &itemName, const std::string &itemDescription)
";

%feature("docstring")  InfoItem::name "std::string InfoItem::name() const 
";

%feature("docstring")  InfoItem::description "std::string InfoItem::description() const 
";


// File: classFit_1_1Kernel.xml
%feature("docstring") Fit::Kernel "

A main class to run fitting.

C++ includes: Kernel.h
";

%feature("docstring")  Fit::Kernel::Kernel "Kernel::Kernel()
";

%feature("docstring")  Fit::Kernel::~Kernel "Kernel::~Kernel()
";

%feature("docstring")  Fit::Kernel::setMinimizer "void Kernel::setMinimizer(const std::string &minimizerName, const std::string &algorithmName=\"\", const std::string &options=\"\")
";

%feature("docstring")  Fit::Kernel::minimize "MinimizerResult Kernel::minimize(fcn_scalar_t fcn, const Parameters &parameters)
";

%feature("docstring")  Fit::Kernel::minimize "MinimizerResult Kernel::minimize(fcn_residual_t fcn, const Parameters &parameters)
";


// File: classFit_1_1Minimizer.xml
%feature("docstring") Fit::Minimizer "

A main class to run fitting.

C++ includes: Minimizer.h
";

%feature("docstring")  Fit::Minimizer::Minimizer "Minimizer::Minimizer()
";

%feature("docstring")  Fit::Minimizer::~Minimizer "Minimizer::~Minimizer()
";

%feature("docstring")  Fit::Minimizer::setMinimizer "void Minimizer::setMinimizer(const std::string &minimizerName, const std::string &algorithmName=\"\", const std::string &options=\"\")
";

%feature("docstring")  Fit::Minimizer::minimize "MinimizerResult Minimizer::minimize(fcn_scalar_t fcn, const Parameters &parameters)
";

%feature("docstring")  Fit::Minimizer::minimize "MinimizerResult Minimizer::minimize(fcn_residual_t fcn, const Parameters &parameters)
";

%feature("docstring")  Fit::Minimizer::minimize "MinimizerResult Minimizer::minimize(PyCallback &callback, const Parameters &parameters)

Finds minimum of user objective function (to be called from Python). 
";


// File: classMinimizerCatalogue.xml
%feature("docstring") MinimizerCatalogue "

Hard-coded information about all minimizers available.

C++ includes: MinimizerCatalogue.h
";

%feature("docstring")  MinimizerCatalogue::MinimizerCatalogue "MinimizerCatalogue::MinimizerCatalogue()
";

%feature("docstring")  MinimizerCatalogue::toString "std::string MinimizerCatalogue::toString() const

Returns multiline string representing catalogue content. 
";

%feature("docstring")  MinimizerCatalogue::minimizerNames "std::vector< std::string > MinimizerCatalogue::minimizerNames() const 
";

%feature("docstring")  MinimizerCatalogue::algorithmNames "std::vector< std::string > MinimizerCatalogue::algorithmNames(const std::string &minimizerName) const

Returns list of algorithms defined for the minimizer with a given name. 
";

%feature("docstring")  MinimizerCatalogue::algorithmDescriptions "std::vector< std::string > MinimizerCatalogue::algorithmDescriptions(const std::string &minimizerName) const

Returns list of algorithm's descriptions for the minimizer with a given name . 
";

%feature("docstring")  MinimizerCatalogue::minimizerInfo "const MinimizerInfo & MinimizerCatalogue::minimizerInfo(const std::string &minimizerName) const

Returns info for minimizer with given name. 
";


// File: classMinimizerFactory.xml
%feature("docstring") MinimizerFactory "

Factory to create minimizers.

C++ includes: MinimizerFactory.h
";


// File: classMinimizerInfo.xml
%feature("docstring") MinimizerInfo "

Info about a minimizer, including list of defined minimization algorithms.

C++ includes: MinimizerInfo.h
";

%feature("docstring")  MinimizerInfo::MinimizerInfo "MinimizerInfo::MinimizerInfo()
";

%feature("docstring")  MinimizerInfo::MinimizerInfo "MinimizerInfo::MinimizerInfo(const std::string &minimizerType, const std::string &minimizerDescription)
";

%feature("docstring")  MinimizerInfo::setAlgorithmName "void MinimizerInfo::setAlgorithmName(const std::string &algorithmName)

Sets currently active algorithm. 
";

%feature("docstring")  MinimizerInfo::algorithmName "std::string MinimizerInfo::algorithmName() const 
";

%feature("docstring")  MinimizerInfo::algorithmNames "std::vector< std::string > MinimizerInfo::algorithmNames() const

Return list of defined algorithm names. 
";

%feature("docstring")  MinimizerInfo::algorithmDescriptions "std::vector< std::string > MinimizerInfo::algorithmDescriptions() const

Returns list of string with description of all available algorithms. 
";


// File: classMinimizerOptions.xml
%feature("docstring") MinimizerOptions "

Collection of internal minimizer settings.

C++ includes: MinimizerOptions.h
";

%feature("docstring")  MinimizerOptions::toOptionString "std::string MinimizerOptions::toOptionString() const

Returns string with all options (i.e. \"Strategy=1;Tolerance=0.01;\") 
";

%feature("docstring")  MinimizerOptions::setOptionString "void MinimizerOptions::setOptionString(const std::string &options)

Set options from their string representation. 
";


// File: classFit_1_1MinimizerResult.xml
%feature("docstring") Fit::MinimizerResult "

Result of minimization round.

C++ includes: MinimizerResult.h
";

%feature("docstring")  Fit::MinimizerResult::MinimizerResult "MinimizerResult::MinimizerResult()
";

%feature("docstring")  Fit::MinimizerResult::setParameters "void MinimizerResult::setParameters(const Parameters &parameters)
";

%feature("docstring")  Fit::MinimizerResult::parameters "Parameters MinimizerResult::parameters() const 
";

%feature("docstring")  Fit::MinimizerResult::setMinValue "void MinimizerResult::setMinValue(double value)
";

%feature("docstring")  Fit::MinimizerResult::minValue "double MinimizerResult::minValue() const

Minimum value of objective function found by minimizer. 
";

%feature("docstring")  Fit::MinimizerResult::toString "std::string MinimizerResult::toString() const

Returns multi-line string representing minimization results. 
";

%feature("docstring")  Fit::MinimizerResult::setReport "void MinimizerResult::setReport(const std::string &value)
";

%feature("docstring")  Fit::MinimizerResult::setDuration "void MinimizerResult::setDuration(double value)
";

%feature("docstring")  Fit::MinimizerResult::setNumberOfCalls "void MinimizerResult::setNumberOfCalls(int value)
";

%feature("docstring")  Fit::MinimizerResult::setNumberOfGradientCalls "void MinimizerResult::setNumberOfGradientCalls(int value)
";


// File: classMinimizerResultsHelper.xml
%feature("docstring") MinimizerResultsHelper "

Contains all logic to generate reports with the result of minimization.

C++ includes: MinimizerResultsHelper.h
";

%feature("docstring")  MinimizerResultsHelper::MinimizerResultsHelper "MinimizerResultsHelper::MinimizerResultsHelper()
";


// File: classMinuit2Minimizer.xml
%feature("docstring") Minuit2Minimizer "

Wrapper for the CERN ROOT facade of the Minuit2 minimizer. See Minuit2 user manual https://root.cern.ch/root/htmldoc/guides/minuit2/Minuit2.pdf.

C++ includes: Minuit2Minimizer.h
";

%feature("docstring")  Minuit2Minimizer::Minuit2Minimizer "Minuit2Minimizer::Minuit2Minimizer(const std::string &algorithmName=AlgorithmNames::Migrad)
";

%feature("docstring")  Minuit2Minimizer::~Minuit2Minimizer "Minuit2Minimizer::~Minuit2Minimizer()
";

%feature("docstring")  Minuit2Minimizer::setStrategy "void Minuit2Minimizer::setStrategy(int value)

Sets minimization strategy (0-low, 1-medium, 2-high minimization quality). At low quality number of function calls will be economized. 
";

%feature("docstring")  Minuit2Minimizer::strategy "int Minuit2Minimizer::strategy() const 
";

%feature("docstring")  Minuit2Minimizer::setErrorDefinition "void Minuit2Minimizer::setErrorDefinition(double value)

Sets error definition factor for parameter error calculation. If objective function (OF) is the usual chisquare function and if the user wants the usual one-standard-deviation errors, then the error definition should be 1.0. If OF is a negative-log-likelihood function, then 0.5. If OF is a chisquare, but the user wants two-standard-deviation errors, 4.0. 
";

%feature("docstring")  Minuit2Minimizer::errorDefinition "double Minuit2Minimizer::errorDefinition() const

Sets tolerance on the function value at the minimum. Minimization will stop when the estimated vertical distance to the minimum (EDM) is less than 0.001*tolerance*ErrorDef. Here ErrorDef=1.0 for chi squared fit and ErrorDef=0.5 for negative log likelihood fit. 
";

%feature("docstring")  Minuit2Minimizer::setTolerance "void Minuit2Minimizer::setTolerance(double value)
";

%feature("docstring")  Minuit2Minimizer::tolerance "double Minuit2Minimizer::tolerance() const

Sets relative floating point arithmetic precision. Should be adjusted when the user knows that objectiove function value is not calculated to the nominal machine accuracy. Typical values are between 10^-5 and 10^-14. 
";

%feature("docstring")  Minuit2Minimizer::setPrecision "void Minuit2Minimizer::setPrecision(double value)
";

%feature("docstring")  Minuit2Minimizer::precision "double Minuit2Minimizer::precision() const 
";

%feature("docstring")  Minuit2Minimizer::setPrintLevel "void Minuit2Minimizer::setPrintLevel(int value)

Sets minimizer internal print level. Default value is 0 (silent). 
";

%feature("docstring")  Minuit2Minimizer::printLevel "int Minuit2Minimizer::printLevel() const 
";

%feature("docstring")  Minuit2Minimizer::setMaxFunctionCalls "void Minuit2Minimizer::setMaxFunctionCalls(int value)

Sets maximum number of objective function calls. 
";

%feature("docstring")  Minuit2Minimizer::maxFunctionCalls "int Minuit2Minimizer::maxFunctionCalls() const 
";

%feature("docstring")  Minuit2Minimizer::statusToString "std::string Minuit2Minimizer::statusToString() const override

Returns string representation of current minimizer status. 
";

%feature("docstring")  Minuit2Minimizer::statusMap "std::map< std::string, std::string > Minuit2Minimizer::statusMap() const override

Returns map of string representing different minimizer statuses. 
";


// File: classMultiOption.xml
%feature("docstring") MultiOption "

Stores a single option for minimization algorithm. Int, double, string values are available. Relies on boost::variant, will be switched to std::variant in C++-17.

C++ includes: MultiOption.h
";

%feature("docstring")  MultiOption::MultiOption "MultiOption::MultiOption(const std::string &name=std::string())
";

%feature("docstring")  MultiOption::MultiOption "MultiOption::MultiOption(const std::string &name, const T &t, const std::string &descripion=std::string())
";

%feature("docstring")  MultiOption::name "std::string MultiOption::name() const 
";

%feature("docstring")  MultiOption::description "std::string MultiOption::description() const 
";

%feature("docstring")  MultiOption::setDescription "void MultiOption::setDescription(const std::string &description)
";

%feature("docstring")  MultiOption::value "MultiOption::variant_t & MultiOption::value()
";

%feature("docstring")  MultiOption::defaultValue "MultiOption::variant_t & MultiOption::defaultValue()
";

%feature("docstring")  MultiOption::get "T MultiOption::get() const

Returns the option's value. 
";

%feature("docstring")  MultiOption::getDefault "T MultiOption::getDefault() const

Returns the option's default value (i.e. used during construction) 
";

%feature("docstring")  MultiOption::setFromString "void MultiOption::setFromString(const std::string &value)

Sets the value of option from string. TODO find more elegant way (without if/else and boost::lexical_cast 
";


// File: classObjectiveFunction.xml
%feature("docstring") ObjectiveFunction "

Information about an objective function, i.e. a function that shall be minimized.

C++ includes: ObjectiveFunction.h
";

%feature("docstring")  ObjectiveFunction::ObjectiveFunction "ObjectiveFunction::ObjectiveFunction()
";

%feature("docstring")  ObjectiveFunction::setObjectiveFunction "void ObjectiveFunction::setObjectiveFunction(objective_function_t func)
";

%feature("docstring")  ObjectiveFunction::setGradientFunction "void ObjectiveFunction::setGradientFunction(gradient_function_t func, int ndatasize)
";

%feature("docstring")  ObjectiveFunction::evaluate "double ObjectiveFunction::evaluate(const std::vector< double > &pars)

Evaluates the value of the function for given vector of function parameters using callback mechanism. 
";

%feature("docstring")  ObjectiveFunction::evaluate_gradient "double ObjectiveFunction::evaluate_gradient(const std::vector< double > &pars, int index, std::vector< double > &gradient)

Evaluates residual and gradients of the function for given vector of function parameters and index of dataelement using callback mechanism. 
";

%feature("docstring")  ObjectiveFunction::functionCalls "int ObjectiveFunction::functionCalls() const 
";

%feature("docstring")  ObjectiveFunction::sizeOfData "int ObjectiveFunction::sizeOfData() const 
";


// File: classFit_1_1ObjectiveFunctionAdapter.xml
%feature("docstring") Fit::ObjectiveFunctionAdapter "

Converts user objective function to function ROOT expects. Handles time of life of function objects.

C++ includes: ObjectiveFunctionAdapter.h
";

%feature("docstring")  Fit::ObjectiveFunctionAdapter::ObjectiveFunctionAdapter "ObjectiveFunctionAdapter::ObjectiveFunctionAdapter()
";

%feature("docstring")  Fit::ObjectiveFunctionAdapter::~ObjectiveFunctionAdapter "ObjectiveFunctionAdapter::~ObjectiveFunctionAdapter()
";

%feature("docstring")  Fit::ObjectiveFunctionAdapter::rootObjectiveFunction "const RootObjectiveFunction * ObjectiveFunctionAdapter::rootObjectiveFunction(fcn_scalar_t fcn, const Parameters &parameters)
";

%feature("docstring")  Fit::ObjectiveFunctionAdapter::rootResidualFunction "const RootResidualFunction * ObjectiveFunctionAdapter::rootResidualFunction(fcn_residual_t fcn, const Parameters &parameters)
";

%feature("docstring")  Fit::ObjectiveFunctionAdapter::numberOfCalls "int ObjectiveFunctionAdapter::numberOfCalls() const 
";

%feature("docstring")  Fit::ObjectiveFunctionAdapter::numberOfGradientCalls "int ObjectiveFunctionAdapter::numberOfGradientCalls() const 
";


// File: classOptionContainer.xml
%feature("docstring") OptionContainer "

Stores multi option (int,double,string) in a container.

C++ includes: OptionContainer.h
";

%feature("docstring")  OptionContainer::OptionContainer "OptionContainer::OptionContainer()
";

%feature("docstring")  OptionContainer::OptionContainer "OptionContainer::OptionContainer(const OptionContainer &other)

Returns true if option with such name already exists. 
";

%feature("docstring")  OptionContainer::addOption "OptionContainer::option_t OptionContainer::addOption(const std::string &optionName, T value, const std::string &description=std::string())
";

%feature("docstring")  OptionContainer::option "OptionContainer::option_t OptionContainer::option(const std::string &optionName)
";

%feature("docstring")  OptionContainer::option "const OptionContainer::option_t OptionContainer::option(const std::string &optionName) const 
";

%feature("docstring")  OptionContainer::optionValue "T OptionContainer::optionValue(const std::string &optionName) const 
";

%feature("docstring")  OptionContainer::setOptionValue "void OptionContainer::setOptionValue(const std::string &optionName, T value)

Sets the value of option. Option should hold same value type already. 
";

%feature("docstring")  OptionContainer::begin "iterator OptionContainer::begin()
";

%feature("docstring")  OptionContainer::begin "const_iterator OptionContainer::begin() const 
";

%feature("docstring")  OptionContainer::end "iterator OptionContainer::end()
";

%feature("docstring")  OptionContainer::end "const_iterator OptionContainer::end() const 
";

%feature("docstring")  OptionContainer::size "size_t OptionContainer::size() const 
";


// File: classFit_1_1Parameter.xml
%feature("docstring") Fit::Parameter "

A fittable parameter with value, error, step, and limits.

C++ includes: Parameter.h
";

%feature("docstring")  Fit::Parameter::Parameter "Parameter::Parameter()
";

%feature("docstring")  Fit::Parameter::Parameter "Parameter::Parameter(const std::string &name, double value, const AttLimits &limits=AttLimits::limitless(), double step=0.0)

Fit parameter constructor.

Parameters:
-----------

name: 
unique name of fit parameters

value: 
starting value of fit parameter

limits: 
fit parameter limits

step: 
initial step of fit parameter during the minimization, will be calculated automatically, if zero. 
";

%feature("docstring")  Fit::Parameter::name "std::string Parameter::name() const 
";

%feature("docstring")  Fit::Parameter::startValue "double Parameter::startValue() const 
";

%feature("docstring")  Fit::Parameter::limits "AttLimits Parameter::limits() const 
";

%feature("docstring")  Fit::Parameter::value "double Parameter::value() const 
";

%feature("docstring")  Fit::Parameter::setValue "void Parameter::setValue(double value)
";

%feature("docstring")  Fit::Parameter::step "double Parameter::step() const 
";

%feature("docstring")  Fit::Parameter::error "double Parameter::error() const 
";

%feature("docstring")  Fit::Parameter::setError "void Parameter::setError(double value)
";


// File: classFit_1_1Parameters.xml
%feature("docstring") Fit::Parameters "

A collection of fit parameters.

C++ includes: Parameters.h
";

%feature("docstring")  Fit::Parameters::Parameters "Fit::Parameters::Parameters()=default
";

%feature("docstring")  Fit::Parameters::add "void Parameters::add(const Parameter &par)
";

%feature("docstring")  Fit::Parameters::begin "Parameters::const_iterator Parameters::begin() const 
";

%feature("docstring")  Fit::Parameters::end "Parameters::const_iterator Parameters::end() const 
";

%feature("docstring")  Fit::Parameters::begin "Parameters::iterator Parameters::begin()
";

%feature("docstring")  Fit::Parameters::end "Parameters::iterator Parameters::end()
";

%feature("docstring")  Fit::Parameters::size "size_t Parameters::size() const 
";

%feature("docstring")  Fit::Parameters::values "std::vector< double > Parameters::values() const 
";

%feature("docstring")  Fit::Parameters::setValues "void Parameters::setValues(const std::vector< double > &values)
";

%feature("docstring")  Fit::Parameters::errors "std::vector< double > Parameters::errors() const 
";

%feature("docstring")  Fit::Parameters::setErrors "void Parameters::setErrors(const std::vector< double > &errors)
";


// File: classPyCallback.xml
%feature("docstring") PyCallback "

Base class to wrap Python callable and pass it to C++. Used in swig interface file, intended to be overloaded from Python.

C++ includes: PyCallback.h
";

%feature("docstring")  PyCallback::PyCallback "PyCallback::PyCallback(CallbackType callback_type=SCALAR)
";

%feature("docstring")  PyCallback::~PyCallback "PyCallback::~PyCallback()
";

%feature("docstring")  PyCallback::callback_type "PyCallback::CallbackType PyCallback::callback_type() const 
";

%feature("docstring")  PyCallback::call_scalar "double PyCallback::call_scalar(Fit::Parameters pars)

Call Python callable and returns its result. Intended to be overloaded in Python.

Parameters:
-----------

pars: 
Fit parameters object (intentionally passed by value).

value of objective function. 
";

%feature("docstring")  PyCallback::call_residuals "std::vector< double > PyCallback::call_residuals(Fit::Parameters)

Call Python callable and returns its result. Intended to be overloaded in Python.

Parameters:
-----------

pars: 
Fit parameters object (intentionally passed by value).

vector of residuals 
";


// File: classRealLimits.xml
%feature("docstring") RealLimits "

Limits for a real fit parameter.

C++ includes: RealLimits.h
";

%feature("docstring")  RealLimits::RealLimits "RealLimits::RealLimits()
";

%feature("docstring")  RealLimits::hasLowerLimit "bool RealLimits::hasLowerLimit() const

if has lower limit 
";

%feature("docstring")  RealLimits::getLowerLimit "double RealLimits::getLowerLimit() const

Returns lower limit. 
";

%feature("docstring")  RealLimits::setLowerLimit "void RealLimits::setLowerLimit(double value)

Sets lower limit. 
";

%feature("docstring")  RealLimits::removeLowerLimit "void RealLimits::removeLowerLimit()

remove lower limit 
";

%feature("docstring")  RealLimits::hasUpperLimit "bool RealLimits::hasUpperLimit() const

if has upper limit 
";

%feature("docstring")  RealLimits::getUpperLimit "double RealLimits::getUpperLimit() const

Returns upper limit. 
";

%feature("docstring")  RealLimits::setUpperLimit "void RealLimits::setUpperLimit(double value)

Sets upper limit. 
";

%feature("docstring")  RealLimits::removeUpperLimit "void RealLimits::removeUpperLimit()

remove upper limit 
";

%feature("docstring")  RealLimits::hasLowerAndUpperLimits "bool RealLimits::hasLowerAndUpperLimits() const

if has lower and upper limit 
";

%feature("docstring")  RealLimits::setLimits "void RealLimits::setLimits(double xmin, double xmax)

Sets lower and upper limits. 
";

%feature("docstring")  RealLimits::removeLimits "void RealLimits::removeLimits()

remove limits 
";

%feature("docstring")  RealLimits::isInRange "bool RealLimits::isInRange(double value) const

returns true if proposed value is in limits range 
";

%feature("docstring")  RealLimits::toString "std::string RealLimits::toString() const 
";

%feature("docstring")  RealLimits::isLimitless "bool RealLimits::isLimitless() const 
";

%feature("docstring")  RealLimits::isPositive "bool RealLimits::isPositive() const 
";

%feature("docstring")  RealLimits::isNonnegative "bool RealLimits::isNonnegative() const 
";

%feature("docstring")  RealLimits::isLowerLimited "bool RealLimits::isLowerLimited() const 
";

%feature("docstring")  RealLimits::isUpperLimited "bool RealLimits::isUpperLimited() const 
";

%feature("docstring")  RealLimits::isLimited "bool RealLimits::isLimited() const 
";


// File: classFit_1_1ResidualFunctionAdapter.xml
%feature("docstring") Fit::ResidualFunctionAdapter "

Provides  RootResidualFunction which will be minimizer by ROOT. Converts ROOT calls to the call of fcn_residual_t.

C++ includes: ResidualFunctionAdapter.h
";

%feature("docstring")  Fit::ResidualFunctionAdapter::ResidualFunctionAdapter "ResidualFunctionAdapter::ResidualFunctionAdapter(fcn_residual_t func, const Parameters &parameters)
";

%feature("docstring")  Fit::ResidualFunctionAdapter::rootResidualFunction "const RootResidualFunction * ResidualFunctionAdapter::rootResidualFunction()
";


// File: classRootGradientFunction.xml
%feature("docstring") RootGradientFunction "

Minimizer function with access to single data element residuals, required by Fumili, Fumili2 and GSLMultiMin minimizers.

C++ includes: RootMinimizerFunctions.h
";

%feature("docstring")  RootGradientFunction::RootGradientFunction "RootGradientFunction::RootGradientFunction(root_gradient_t fun_gradient, size_t npars, size_t ndatasize)
";

%feature("docstring")  RootGradientFunction::Type "Type_t RootGradientFunction::Type() const 
";

%feature("docstring")  RootGradientFunction::Clone "ROOT::Math::IMultiGenFunction* RootGradientFunction::Clone() const 
";

%feature("docstring")  RootGradientFunction::DataElement "double RootGradientFunction::DataElement(const double *pars, unsigned int i_data, double *gradient=0) const

evaluation of single data element residual 
";


// File: classRootMinimizerAdapter.xml
%feature("docstring") RootMinimizerAdapter "

Pure virtual interface that adapts the CERN ROOT minimizer to our  IMinimizer.

C++ includes: RootMinimizerAdapter.h
";

%feature("docstring")  RootMinimizerAdapter::~RootMinimizerAdapter "RootMinimizerAdapter::~RootMinimizerAdapter()
";

%feature("docstring")  RootMinimizerAdapter::minimize "void RootMinimizerAdapter::minimize() override

run minimization 
";

%feature("docstring")  RootMinimizerAdapter::minimize_scalar "MinimizerResult RootMinimizerAdapter::minimize_scalar(fcn_scalar_t fcn, Fit::Parameters parameters) override
";

%feature("docstring")  RootMinimizerAdapter::minimize_residual "MinimizerResult RootMinimizerAdapter::minimize_residual(fcn_residual_t fcn, Fit::Parameters parameters) override
";

%feature("docstring")  RootMinimizerAdapter::minimizerName "std::string RootMinimizerAdapter::minimizerName() const overridefinal

Returns name of the minimizer. 
";

%feature("docstring")  RootMinimizerAdapter::algorithmName "std::string RootMinimizerAdapter::algorithmName() const overridefinal

Returns name of the minimization algorithm. 
";

%feature("docstring")  RootMinimizerAdapter::setParameters "void RootMinimizerAdapter::setParameters(const FitParameterSet &parameters) overridefinal

Sets internal minimizer parameters using external parameter list. 
";

%feature("docstring")  RootMinimizerAdapter::setParameters "void RootMinimizerAdapter::setParameters(const Fit::Parameters &parameters)
";

%feature("docstring")  RootMinimizerAdapter::setObjectiveFunction "void RootMinimizerAdapter::setObjectiveFunction(objective_function_t func) overridefinal
";

%feature("docstring")  RootMinimizerAdapter::setGradientFunction "void RootMinimizerAdapter::setGradientFunction(gradient_function_t func, int ndatasize) overridefinal
";

%feature("docstring")  RootMinimizerAdapter::minValue "double RootMinimizerAdapter::minValue() const overridefinal

Returns minimum function value. 
";

%feature("docstring")  RootMinimizerAdapter::reportOutcome "std::string RootMinimizerAdapter::reportOutcome() const overridefinal
";

%feature("docstring")  RootMinimizerAdapter::options "MinimizerOptions& RootMinimizerAdapter::options()
";

%feature("docstring")  RootMinimizerAdapter::options "const MinimizerOptions& RootMinimizerAdapter::options() const 
";

%feature("docstring")  RootMinimizerAdapter::statusToString "std::string RootMinimizerAdapter::statusToString() const

Returns string representation of current minimizer status. 
";

%feature("docstring")  RootMinimizerAdapter::providesError "bool RootMinimizerAdapter::providesError() const

Returns true if minimizer provides error and error matrix. 
";

%feature("docstring")  RootMinimizerAdapter::statusMap "std::map< std::string, std::string > RootMinimizerAdapter::statusMap() const

Returns map of string representing different minimizer statuses. 
";

%feature("docstring")  RootMinimizerAdapter::propagateResults "void RootMinimizerAdapter::propagateResults(FitParameterSet &parameters) override

Propagates results of minimization to fit parameter set. 
";

%feature("docstring")  RootMinimizerAdapter::propagateResults "void RootMinimizerAdapter::propagateResults(Fit::Parameters &parameters) override
";

%feature("docstring")  RootMinimizerAdapter::setOptions "void RootMinimizerAdapter::setOptions(const std::string &optionString) overridefinal

Sets option string to the minimizer. 
";


// File: classRootObjectiveFunction.xml
%feature("docstring") RootObjectiveFunction "

The chi2 function for use in minimizers.

C++ includes: RootMinimizerFunctions.h
";

%feature("docstring")  RootObjectiveFunction::RootObjectiveFunction "RootObjectiveFunction::RootObjectiveFunction(root_objective_t fcn, int ndims)
";


// File: classRootObjectiveFunctionAdapter.xml
%feature("docstring") RootObjectiveFunctionAdapter "

Adapts our objective functions to ROOT.

C++ includes: RootObjectiveFuncAdapter.h
";

%feature("docstring")  RootObjectiveFunctionAdapter::RootObjectiveFunctionAdapter "RootObjectiveFunctionAdapter::RootObjectiveFunctionAdapter()
";

%feature("docstring")  RootObjectiveFunctionAdapter::setObjectiveCallback "void RootObjectiveFunctionAdapter::setObjectiveCallback(objective_function_t func)

Sets the function which will be used for finding objective function minimum value. 
";

%feature("docstring")  RootObjectiveFunctionAdapter::setGradientCallback "void RootObjectiveFunctionAdapter::setGradientCallback(gradient_function_t func, int ndatasize)

Sets the function which will be used for gradient calculations. 
";

%feature("docstring")  RootObjectiveFunctionAdapter::setNumberOfParameters "void RootObjectiveFunctionAdapter::setNumberOfParameters(int nparameters)

Sets number of fit parameters (needed to construct correct ROOT's functions). 
";

%feature("docstring")  RootObjectiveFunctionAdapter::rootChiSquaredFunction "const RootObjectiveFunction * RootObjectiveFunctionAdapter::rootChiSquaredFunction()

Creates and returns objective function suitable for ROOT minimizers. 
";

%feature("docstring")  RootObjectiveFunctionAdapter::rootGradientFunction "const RootGradientFunction * RootObjectiveFunctionAdapter::rootGradientFunction()

Creates and returns gradient function suitable for ROOT minimizers. 
";


// File: classRootResidualFunction.xml
%feature("docstring") RootResidualFunction "

Minimizer function with access to single data element residuals, required by Fumili2 and GSLMultiMin minimizers.

C++ includes: RootResidualFunction.h
";

%feature("docstring")  RootResidualFunction::RootResidualFunction "RootResidualFunction::RootResidualFunction(objective_function_t objective_fun, gradient_function_t gradient_fun, size_t npars, size_t ndatasize)

Constructs  RootResidualFunction

Parameters:
-----------

fun_gradient: 
user function to call

npars: 
number of fit parameters

ndatasize: 
number of residual elements in dataset 
";

%feature("docstring")  RootResidualFunction::Type "RootResidualFunction::Type_t RootResidualFunction::Type() const override
";

%feature("docstring")  RootResidualFunction::Clone "ROOT::Math::IMultiGenFunction * RootResidualFunction::Clone() const override
";

%feature("docstring")  RootResidualFunction::DataElement "double RootResidualFunction::DataElement(const double *pars, unsigned int index, double *gradients=0) const override

Evaluation of single data element residual. Will be called by ROOT minimizer.

Returns residual value for given data element index. Transform call of ancient pointer based function to safer gradient_function_t.

Parameters:
-----------

pars: 
array of fit parameter values from the minimizer

index: 
index of residual element

gradients: 
if not zero, then array where we have to put gradients

value of residual for given data element index 
";


// File: classFit_1_1ScalarFunctionAdapter.xml
%feature("docstring") Fit::ScalarFunctionAdapter "

Converts user objective function to chi2 like function which ROOT expects.

More precisely, ROOT call to std::function<double(const double*)> will cause the call of user function std::function<double(std::vector<double>)>, where function input parameters will be current values fit parameters.

C++ includes: ScalarFunctionAdapter.h
";

%feature("docstring")  Fit::ScalarFunctionAdapter::ScalarFunctionAdapter "ScalarFunctionAdapter::ScalarFunctionAdapter(fcn_scalar_t func, const Parameters &parameters)
";

%feature("docstring")  Fit::ScalarFunctionAdapter::rootObjectiveFunction "const RootObjectiveFunction * ScalarFunctionAdapter::rootObjectiveFunction()
";


// File: classSimAnMinimizer.xml
%feature("docstring") SimAnMinimizer "

Wrapper for the CERN ROOT facade of the GSL simmulated annealing minimizer.

C++ includes: SimAnMinimizer.h
";

%feature("docstring")  SimAnMinimizer::SimAnMinimizer "SimAnMinimizer::SimAnMinimizer()
";

%feature("docstring")  SimAnMinimizer::~SimAnMinimizer "SimAnMinimizer::~SimAnMinimizer()
";

%feature("docstring")  SimAnMinimizer::setPrintLevel "void SimAnMinimizer::setPrintLevel(int value)

Sets minimizer internal print level. Default value is 0 (silent). 
";

%feature("docstring")  SimAnMinimizer::printLevel "int SimAnMinimizer::printLevel() const 
";

%feature("docstring")  SimAnMinimizer::setMaxIterations "void SimAnMinimizer::setMaxIterations(int value)

Sets maximum number of iterations to try at each step. 
";

%feature("docstring")  SimAnMinimizer::maxIterations "int SimAnMinimizer::maxIterations() const 
";

%feature("docstring")  SimAnMinimizer::setIterationsAtEachTemp "void SimAnMinimizer::setIterationsAtEachTemp(int value)

Sets number of iterations at each temperature. 
";

%feature("docstring")  SimAnMinimizer::iterationsAtEachTemp "int SimAnMinimizer::iterationsAtEachTemp() const 
";

%feature("docstring")  SimAnMinimizer::setStepSize "void SimAnMinimizer::setStepSize(double value)

Sets max step size used in random walk. 
";

%feature("docstring")  SimAnMinimizer::stepSize "double SimAnMinimizer::stepSize() const 
";

%feature("docstring")  SimAnMinimizer::setBoltzmannK "void SimAnMinimizer::setBoltzmannK(double value)

Sets Boltzmann distribution parameter: k. 
";

%feature("docstring")  SimAnMinimizer::boltzmannK "double SimAnMinimizer::boltzmannK() const 
";

%feature("docstring")  SimAnMinimizer::setBoltzmannInitialTemp "void SimAnMinimizer::setBoltzmannInitialTemp(double value)

Sets Boltzmann distribution parameter: initial temperature. 
";

%feature("docstring")  SimAnMinimizer::boltzmannInitialTemp "double SimAnMinimizer::boltzmannInitialTemp() const 
";

%feature("docstring")  SimAnMinimizer::setBoltzmannMu "void SimAnMinimizer::setBoltzmannMu(double value)

Sets Boltzmann distribution parameter: mu. 
";

%feature("docstring")  SimAnMinimizer::boltzmannMu "double SimAnMinimizer::boltzmannMu() const 
";

%feature("docstring")  SimAnMinimizer::setBoltzmannMinTemp "void SimAnMinimizer::setBoltzmannMinTemp(double value)

Sets Boltzmann distribution parameter: minimal temperature. 
";

%feature("docstring")  SimAnMinimizer::boltzmannMinTemp "double SimAnMinimizer::boltzmannMinTemp() const 
";

%feature("docstring")  SimAnMinimizer::statusMap "std::map< std::string, std::string > SimAnMinimizer::statusMap() const override

Returns map of string representing different minimizer statuses. 
";

%feature("docstring")  SimAnMinimizer::isGradientBasedAgorithm "bool SimAnMinimizer::isGradientBasedAgorithm() override
";


// File: classTestMinimizer.xml
%feature("docstring") TestMinimizer "

A trivial minimizer that calls the objective function once. Used to test the whole chain.

C++ includes: TestMinimizer.h
";

%feature("docstring")  TestMinimizer::TestMinimizer "TestMinimizer::TestMinimizer()
";

%feature("docstring")  TestMinimizer::~TestMinimizer "TestMinimizer::~TestMinimizer()
";

%feature("docstring")  TestMinimizer::minimizerName "std::string TestMinimizer::minimizerName() const final

return name of the minimizer 
";

%feature("docstring")  TestMinimizer::algorithmName "std::string TestMinimizer::algorithmName() const final

return name of the minimization algorithm 
";

%feature("docstring")  TestMinimizer::minimize "void TestMinimizer::minimize() override

run minimization 
";

%feature("docstring")  TestMinimizer::setParameters "void TestMinimizer::setParameters(const FitParameterSet &parameters) override

Sets internal minimizer parameters using external parameter list. 
";

%feature("docstring")  TestMinimizer::setObjectiveFunction "void TestMinimizer::setObjectiveFunction(objective_function_t func) override
";

%feature("docstring")  TestMinimizer::reportOutcome "std::string TestMinimizer::reportOutcome() const override
";

%feature("docstring")  TestMinimizer::propagateResults "void TestMinimizer::propagateResults(FitParameterSet &) override

Propagates results of minimization to fit parameter set. 
";

%feature("docstring")  TestMinimizer::minimize_scalar "MinimizerResult TestMinimizer::minimize_scalar(fcn_scalar_t fcn, Fit::Parameters parameters) override
";


// File: classTimeInterval.xml
%feature("docstring") TimeInterval "";

%feature("docstring")  TimeInterval::TimeInterval "TimeInterval::TimeInterval()
";

%feature("docstring")  TimeInterval::~TimeInterval "TimeInterval::~TimeInterval()
";

%feature("docstring")  TimeInterval::start "void TimeInterval::start()
";

%feature("docstring")  TimeInterval::stop "void TimeInterval::stop()
";

%feature("docstring")  TimeInterval::runTime "double TimeInterval::runTime() const

returns run time in sec.msec 
";


// File: classTimeIntervalImp.xml
%feature("docstring") TimeIntervalImp "";

%feature("docstring")  TimeIntervalImp::TimeIntervalImp "TimeIntervalImp::TimeIntervalImp()
";


// File: namespace_0D0.xml


// File: namespace_0D20.xml


// File: namespace_0D28.xml


// File: namespace_0D34.xml


// File: namespace_0D39.xml


// File: namespace_0D54.xml


// File: namespace_0D56.xml


// File: namespace_0D60.xml


// File: namespace_0D62.xml


// File: namespaceAlgorithmNames.xml


// File: namespaceFit.xml


// File: namespaceMinimizerNames.xml


// File: namespaceMinimizerUtils.xml
%feature("docstring")  MinimizerUtils::toString "std::string MinimizerUtils::toString(const std::vector< std::string > &v, const std::string &delim=\"\")
";

%feature("docstring")  MinimizerUtils::gslErrorDescriptionMap "std::map< int, std::string > MinimizerUtils::gslErrorDescriptionMap()

Returns translation of GSL error code to string. 
";

%feature("docstring")  MinimizerUtils::gslErrorDescription "std::string MinimizerUtils::gslErrorDescription(int errorCode)
";

%feature("docstring")  MinimizerUtils::numbersDiffer "bool MinimizerUtils::numbersDiffer(double a, double b, double tol)
";

%feature("docstring")  MinimizerUtils::sectionString "std::string MinimizerUtils::sectionString(const std::string &sectionName=\"\", int report_width=80)

Returns horizontal line of 80 characters length with section name in it. 
";


// File: namespaceOptionNames.xml


// File: namespaceROOT.xml


// File: namespaceROOT_1_1Math.xml


// File: namespaceROOT_1_1Minuit2.xml


// File: namespaceStringUtils.xml
%feature("docstring")  StringUtils::matchesPattern "bool StringUtils::matchesPattern(const std::string &text, const std::string &wildcardPattern)

Returns true if text matches pattern with wildcards '*' and '?'. 
";

%feature("docstring")  StringUtils::padRight "std::string StringUtils::padRight(const std::string &name, int length)

Returns string right-padded with blanks. 
";

%feature("docstring")  StringUtils::split "std::vector< std::string > StringUtils::split(const std::string &text, const std::string &delimeter)

Split string into vector of string using delimeter.

Returns token vector obtained by splitting string at delimiters. 
";

%feature("docstring")  StringUtils::replaceItemsFromString "void StringUtils::replaceItemsFromString(std::string &text, const std::vector< std::string > &items, const std::string &replacement=\"\")

Replaces all occurences of items from string text with delimiter. 
";

%feature("docstring")  StringUtils::join "std::string StringUtils::join(const std::vector< std::string > &joinable, const std::string &joint)

Returns string obtain by joining vector elements. 
";

%feature("docstring")  StringUtils::removeSubstring "std::string StringUtils::removeSubstring(const std::string &text, const std::string &substr)

Removes multiple occurences of given substring from a string and returns result. 
";

%feature("docstring")  StringUtils::scientific "std::string StringUtils::scientific(const T value, int n=10)

Returns scientific string representing given value of any numeric type. 
";

%feature("docstring")  StringUtils::to_lower "std::string StringUtils::to_lower(std::string text)

Returns new string which is lower case of text. 
";


// File: FitKernel_8cpp.xml


// File: FitKernel_8h.xml


// File: FitKernelImpl_8cpp.xml


// File: FitKernelImpl_8h.xml


// File: MinimizerCatalogue_8cpp.xml


// File: MinimizerCatalogue_8h.xml


// File: MinimizerFactory_8cpp.xml


// File: MinimizerFactory_8h.xml


// File: ObjectiveFunction_8cpp.xml


// File: ObjectiveFunction_8h.xml


// File: IMinimizer_8cpp.xml


// File: IMinimizer_8h.xml


// File: KernelTypes_8h.xml


// File: MinimizerConstants_8h.xml


// File: MinimizerInfo_8cpp.xml


// File: MinimizerInfo_8h.xml


// File: TestMinimizer_8cpp.xml


// File: TestMinimizer_8h.xml


// File: IFunctionAdapter_8cpp.xml


// File: IFunctionAdapter_8h.xml


// File: Kernel_8cpp.xml


// File: Kernel_8h.xml


// File: Minimizer_8cpp.xml


// File: Minimizer_8h.xml


// File: MinimizerResult_8cpp.xml


// File: MinimizerResult_8h.xml


// File: ObjectiveFunctionAdapter_8cpp.xml


// File: ObjectiveFunctionAdapter_8h.xml


// File: Parameter_8cpp.xml


// File: Parameter_8h.xml


// File: Parameters_8cpp.xml


// File: Parameters_8h.xml


// File: PyCallback_8cpp.xml


// File: PyCallback_8h.xml


// File: ResidualFunctionAdapter_8cpp.xml


// File: ResidualFunctionAdapter_8h.xml


// File: ScalarFunctionAdapter_8cpp.xml


// File: ScalarFunctionAdapter_8h.xml


// File: FitOptions_8h.xml


// File: MinimizerOptions_8cpp.xml


// File: MinimizerOptions_8h.xml


// File: MultiOption_8cpp.xml


// File: MultiOption_8h.xml


// File: OptionContainer_8cpp.xml


// File: OptionContainer_8h.xml


// File: AttLimits_8cpp.xml


// File: AttLimits_8h.xml


// File: Attributes_8h.xml


// File: FitParameterSet_8cpp.xml


// File: FitParameterSet_8h.xml


// File: IFitParameter_8cpp.xml


// File: IFitParameter_8h.xml


// File: RealLimits_8cpp.xml


// File: RealLimits_8h.xml


// File: GeneticMinimizer_8cpp.xml


// File: GeneticMinimizer_8h.xml


// File: GSLLevenbergMarquardtMinimizer_8cpp.xml


// File: GSLLevenbergMarquardtMinimizer_8h.xml


// File: GSLMultiMinimizer_8cpp.xml


// File: GSLMultiMinimizer_8h.xml


// File: MinimizerResultsHelper_8cpp.xml


// File: MinimizerResultsHelper_8h.xml


// File: Minuit2Minimizer_8cpp.xml


// File: Minuit2Minimizer_8h.xml


// File: RootMinimizerAdapter_8cpp.xml


// File: RootMinimizerAdapter_8h.xml


// File: RootMinimizerFunctions_8h.xml


// File: RootObjectiveFuncAdapter_8cpp.xml


// File: RootObjectiveFuncAdapter_8h.xml


// File: RootResidualFunction_8cpp.xml


// File: RootResidualFunction_8h.xml


// File: SimAnMinimizer_8cpp.xml


// File: SimAnMinimizer_8h.xml


// File: MinimizerUtils_8cpp.xml


// File: MinimizerUtils_8h.xml


// File: StringUtils_8cpp.xml


// File: StringUtils_8h.xml


// File: TimeInterval_8cpp.xml


// File: TimeInterval_8h.xml


// File: dir_d0c8f8fb9032c27878972645c4679f14.xml


// File: dir_befad91b6aded329d87ab1464acca32e.xml


// File: dir_f9473c719213b1ce2ec7fbf8aef1535c.xml


// File: dir_f668eca225435178269b3663d40ba22e.xml


// File: dir_8609ab863c9692d0c6e768a2f88f7f85.xml


// File: dir_154d691091a050434159f2fb00439691.xml


// File: dir_1acb97a05207425a4804447756e3d919.xml


// File: dir_50776eae6dbf3f787dd8fd4106a9bdd2.xml


// File: dir_111d40054bb7ae6116a9a4a5aab3a0b8.xml

